AlekSIS (School Information System) — App for Untis import
==========================================================

AlekSIS
-------

This is an application for use with the `AlekSIS®`_ platform.

Features
--------

* Import absence reasons
* Import absences
* Import breaks
* Import classes
* Import events
* Import exported Untis database via MySQL import
* Import exported Untis XML files
* Import holidays
* Import lessons
* Import rooms
* Import subjects
* Import substitutions
* Import supervision areas
* Import teachers
* Import time periods

Licence
-------

::

  Copyright © 2018, 2019, 2020, 2021 Jonathan Weth <dev@jonathanweth.de>
  Copyright © 2018, 2019 Frank Poetzsch-Heffter <p-h@katharineum.de>
  Copyright © 2019, 2020, 2021, 2022 Dominik George <dominik.george@teckids.org>
  Copyright © 2019, 2020 Tom Teichler <tom.teichler@teckids.org>
  Copyright © 2019 Julian Leucker <leuckeju@katharineum.de>
  Copyright © 2019 mirabilos <thorsten.glaser@teckids.org>

  Licenced under the EUPL, version 1.2 or later, by Teckids e.V. (Bonn, Germany).

Please see the LICENCE.rst file accompanying this distribution for the
full licence text or on the `European Union Public Licence`_ website
https://joinup.ec.europa.eu/collection/eupl/guidelines-users-and-developers
(including all other official language versions).

Trademark
---------

AlekSIS® is a registered trademark of the AlekSIS open source project, represented
by Teckids e.V. Please refer to the `trademark policy`_ for hints on using the trademark
AlekSIS®.

.. _AlekSIS®: https://aleksis.org/
.. _European Union Public Licence: https://eupl.eu/
.. _trademark policy: https://aleksis.org/pages/about
